@@ -6,21 +6,19 @@ mod tests {
 
     use crate::apiv1::conn_pool::ConnectionManager;
     use crate::apiv1::spanner_client::Client;
+    use google_cloud_gax::grpc::Code;
     use google_cloud_googleapis::spanner::v1::mutation::{Operation, Write};
     use google_cloud_googleapis::spanner::v1::{
-        commit_request, transaction_options, transaction_selector, BatchCreateSessionsRequest,
-        BeginTransactionRequest, CommitRequest, CreateSessionRequest, DeleteSessionRequest,
-        ExecuteBatchDmlRequest, ExecuteSqlRequest, GetSessionRequest, ListSessionsRequest,
-        PartitionQueryRequest, PartitionReadRequest, ReadRequest, RequestOptions, RollbackRequest,
-        Session, Transaction, TransactionOptions, TransactionSelector,
+        commit_request, transaction_options, transaction_selector, BatchCreateSessionsRequest, BeginTransactionRequest,
+        CommitRequest, CreateSessionRequest, DeleteSessionRequest, ExecuteBatchDmlRequest, ExecuteSqlRequest,
+        GetSessionRequest, ListSessionsRequest, PartitionQueryRequest, PartitionReadRequest, ReadRequest,
+        RequestOptions, RollbackRequest, Session, Transaction, TransactionOptions, TransactionSelector,
     };
     use google_cloud_googleapis::spanner::v1::{execute_batch_dml_request, KeySet, Mutation};
-    use google_cloud_googleapis::Code;
     use prost_types::{value::Kind, ListValue, Value};
     use serial_test::serial;
 
-    const DATABASE: &str =
-        "projects/local-project/instances/test-instance/databases/local-database";
+    const DATABASE: &str = "projects/local-project/instances/test-instance/databases/local-database";
 
     async fn create_spanner_client() -> Client {
         let cm = ConnectionManager::new(1, Some("localhost:9010".to_string()))
@@ -34,7 +32,7 @@ mod tests {
             database: DATABASE.to_string(),
             session: None,
         };
-        let session_response = client.create_session(session_request, None).await.unwrap();
+        let session_response = client.create_session(session_request, None, None).await.unwrap();
         session_response.into_inner()
     }
 
@@ -42,17 +40,15 @@ mod tests {
         let request = BeginTransactionRequest {
             session: session.name.to_string(),
             options: Option::from(TransactionOptions {
-                mode: Option::from(transaction_options::Mode::ReadOnly(
-                    transaction_options::ReadOnly {
-                        return_read_timestamp: false,
-                        timestamp_bound: None,
-                    },
-                )),
+                mode: Option::from(transaction_options::Mode::ReadOnly(transaction_options::ReadOnly {
+                    return_read_timestamp: false,
+                    timestamp_bound: None,
+                })),
             }),
             request_options: None,
         };
         return client
-            .begin_transaction(request, None)
+            .begin_transaction(request, None, None)
             .await
             .unwrap()
             .into_inner();
@@ -62,14 +58,12 @@ mod tests {
         let request = BeginTransactionRequest {
             session: session.name.to_string(),
             options: Option::from(TransactionOptions {
-                mode: Option::from(transaction_options::Mode::ReadWrite(
-                    transaction_options::ReadWrite {},
-                )),
+                mode: Option::from(transaction_options::Mode::ReadWrite(transaction_options::ReadWrite {})),
             }),
             request_options: None,
         };
         return client
-            .begin_transaction(request, None)
+            .begin_transaction(request, None, None)
             .await
             .unwrap()
             .into_inner();
@@ -84,7 +78,7 @@ mod tests {
             session: None,
         };
 
-        match client.create_session(request, None).await {
+        match client.create_session(request, None, None).await {
             Ok(res) => {
                 println!("created session = {}", res.get_ref().name);
                 assert!(!res.get_ref().name.is_empty());
@@ -103,7 +97,7 @@ mod tests {
             session_template: None,
         };
 
-        match client.batch_create_sessions(request, None).await {
+        match client.batch_create_sessions(request, None, None).await {
             Ok(res) => {
                 assert_eq!(
                     res.get_ref().session.len(),
@@ -125,7 +119,7 @@ mod tests {
             name: session.name.to_string(),
         };
 
-        match client.get_session(request, None).await {
+        match client.get_session(request, None, None).await {
             Ok(res) => {
                 assert_eq!(res.get_ref().name, session.name.to_string());
             }
@@ -144,7 +138,7 @@ mod tests {
             filter: "".to_string(),
         };
 
-        match client.list_sessions(request, None).await {
+        match client.list_sessions(request, None, None).await {
             Ok(res) => {
                 println!("list session size = {}", res.get_ref().sessions.len());
             }
@@ -163,10 +157,7 @@ mod tests {
             session_count: 2,
             session_template: None,
         };
-        let session_response = client
-            .batch_create_sessions(batch_request, None)
-            .await
-            .unwrap();
+        let session_response = client.batch_create_sessions(batch_request, None, None).await.unwrap();
         let sessions = &session_response.get_ref().session;
 
         // all delete
@@ -175,7 +166,7 @@ mod tests {
                 name: session.name.to_string(),
             };
 
-            match client.delete_session(request, None).await {
+            match client.delete_session(request, None, None).await {
                 Ok(_) => {}
                 Err(err) => panic!("err: {:?}", err),
             };
@@ -200,7 +191,7 @@ mod tests {
             query_options: None,
             request_options: None,
         };
-        match client.execute_sql(request, None).await {
+        match client.execute_sql(request, None, None).await {
             Ok(res) => {
                 assert_eq!(1, res.into_inner().rows.len());
             }
@@ -227,7 +218,7 @@ mod tests {
             request_options: None,
         };
 
-        let resume_token = match client.execute_streaming_sql(request.clone(), None).await {
+        let resume_token = match client.execute_streaming_sql(request.clone(), None, None).await {
             Ok(res) => {
                 let mut result = res.into_inner();
                 if let Some(next_message) = result.message().await.unwrap() {
@@ -242,7 +233,7 @@ mod tests {
         println!("resume token = {:?}", resume_token.clone().unwrap());
         request.resume_token = resume_token.unwrap();
 
-        match client.execute_streaming_sql(request, None).await {
+        match client.execute_streaming_sql(request, None, None).await {
             Ok(res) => {
                 let mut result = res.into_inner();
                 assert!(!result.message().await.unwrap().unwrap().values.is_empty())
@@ -259,17 +250,15 @@ mod tests {
         let request = BeginTransactionRequest {
             session: session.name.to_string(),
             options: Option::from(TransactionOptions {
-                mode: Option::from(transaction_options::Mode::ReadOnly(
-                    transaction_options::ReadOnly {
-                        return_read_timestamp: false,
-                        timestamp_bound: None,
-                    },
-                )),
+                mode: Option::from(transaction_options::Mode::ReadOnly(transaction_options::ReadOnly {
+                    return_read_timestamp: false,
+                    timestamp_bound: None,
+                })),
             }),
             request_options: None,
         };
 
-        match client.begin_transaction(request, None).await {
+        match client.begin_transaction(request, None, None).await {
             Ok(res) => {
                 let tx_id = res.into_inner().id;
                 println!("tx id is {:?}", tx_id);
@@ -292,12 +281,14 @@ mod tests {
             }),
             statements: vec![
                 execute_batch_dml_request::Statement {
-                    sql: "INSERT INTO Guild (GuildId,OwnerUserId,UpdatedAt) VALUES('1', 'u1', CURRENT_TIMESTAMP())".to_string(),
+                    sql: "INSERT INTO Guild (GuildId,OwnerUserId,UpdatedAt) VALUES('1', 'u1', CURRENT_TIMESTAMP())"
+                        .to_string(),
                     params: None,
                     param_types: Default::default(),
                 },
                 execute_batch_dml_request::Statement {
-                    sql: "INSERT INTO Guild (GuildId,OwnerUserId,UpdatedAt) VALUES('2', 'u2', CURRENT_TIMESTAMP())".to_string(),
+                    sql: "INSERT INTO Guild (GuildId,OwnerUserId,UpdatedAt) VALUES('2', 'u2', CURRENT_TIMESTAMP())"
+                        .to_string(),
                     params: None,
                     param_types: Default::default(),
                 },
@@ -306,7 +297,7 @@ mod tests {
             request_options: None,
         };
 
-        let result = client.execute_batch_dml(request, None).await;
+        let result = client.execute_batch_dml(request, None, None).await;
         client
             .rollback(
                 RollbackRequest {
@@ -314,18 +305,14 @@ mod tests {
                     transaction_id: tx.id,
                 },
                 None,
+                None,
             )
             .await
             .unwrap();
         match result {
             Ok(res) => {
                 let status = res.into_inner().status.unwrap();
-                assert_eq!(
-                    Code::Ok,
-                    Code::from(tonic::Code::from(status.code)),
-                    "gRPC success but error found : {:?}",
-                    status
-                );
+                assert_eq!(Code::Ok, Code::from(status.code), "gRPC success but error found : {:?}", status);
             }
             Err(err) => panic!("err: {:?}", err),
         };
@@ -342,18 +329,17 @@ mod tests {
             transaction: Option::from(TransactionSelector {
                 selector: Option::from(transaction_selector::Selector::Id(tx.id.clone())),
             }),
-            statements: vec![
-                execute_batch_dml_request::Statement {
-                    sql: "INSERT INTO GuildX (GuildId,OwnerUserId,UpdatedAt) VALUES('1', 'u1', CURRENT_TIMESTAMP())".to_string(),
-                    params: None,
-                    param_types: Default::default(),
-                },
-            ],
+            statements: vec![execute_batch_dml_request::Statement {
+                sql: "INSERT INTO GuildX (GuildId,OwnerUserId,UpdatedAt) VALUES('1', 'u1', CURRENT_TIMESTAMP())"
+                    .to_string(),
+                params: None,
+                param_types: Default::default(),
+            }],
             seqno: 0,
             request_options: None,
         };
 
-        let result = client.execute_batch_dml(request, None).await;
+        let result = client.execute_batch_dml(request, None, None).await;
         client
             .rollback(
                 RollbackRequest {
@@ -361,14 +347,12 @@ mod tests {
                     transaction_id: tx.id,
                 },
                 None,
+                None,
             )
             .await
             .unwrap();
         match result {
-            Ok(res) => panic!(
-                "must be error code = {:?}",
-                res.into_inner().status.unwrap().code
-            ),
+            Ok(res) => panic!("must be error code = {:?}", res.into_inner().status.unwrap().code),
             Err(status) => {
                 assert_eq!(
                     Code::InvalidArgument,
@@ -402,7 +386,7 @@ mod tests {
             limit: 0,
         };
 
-        match client.read(request, None).await {
+        match client.read(request, None, None).await {
             Ok(res) => {
                 println!("row size = {:?}", res.into_inner().rows.len());
             }
@@ -432,7 +416,7 @@ mod tests {
             limit: 0,
         };
 
-        match client.streaming_read(request, None).await {
+        match client.streaming_read(request, None, None).await {
             Ok(res) => match res.into_inner().message().await {
                 Ok(..) => {}
                 Err(err) => panic!("err: {:?}", err),
@@ -466,9 +450,7 @@ mod tests {
                                 kind: Some(Kind::StringValue("u1".to_string())),
                             },
                             Value {
-                                kind: Some(Kind::StringValue(
-                                    "spanner.commit_timestamp()".to_string(),
-                                )),
+                                kind: Some(Kind::StringValue("spanner.commit_timestamp()".to_string())),
                             },
                         ],
                     }],
@@ -483,7 +465,7 @@ mod tests {
             return_commit_stats: false,
         };
 
-        match client.commit(request, None).await {
+        match client.commit(request, None, None).await {
             Ok(res) => {
                 assert!(res.into_inner().commit_timestamp.is_some());
             }
@@ -502,7 +484,7 @@ mod tests {
             transaction_id: tx.id,
         };
 
-        match client.rollback(request, None).await {
+        match client.rollback(request, None, None).await {
             Ok(_) => {}
             Err(err) => panic!("err: {:?}", err),
         };
@@ -525,7 +507,7 @@ mod tests {
             partition_options: None,
         };
 
-        match client.partition_query(request, None).await {
+        match client.partition_query(request, None, None).await {
             Ok(res) => {
                 println!("partition count {:?}", res.into_inner().partitions.len());
                 assert_eq!(true, true);
@@ -555,7 +537,7 @@ mod tests {
             key_set: None,
         };
 
-        match client.partition_read(request, None).await {
+        match client.partition_read(request, None, None).await {
             Ok(res) => {
                 println!("partition count {:?}", res.into_inner().partitions.len());
                 assert_eq!(true, true);
