@@ -5,12 +5,11 @@ use chrono::{DateTime, NaiveDate, ParseError, Utc};
 use prost_types::value::Kind;
 use prost_types::{value, Value};
 
-use crate::value::CommitTimestamp;
+use crate::value::{CommitTimestamp, SpannerNumeric};
 use base64::DecodeError;
 use google_cloud_googleapis::spanner::v1::struct_type::Field;
 use google_cloud_googleapis::spanner::v1::StructType;
 use std::num::ParseIntError;
-use std::str::FromStr;
 
 #[derive(Clone)]
 pub struct Row {
@@ -31,8 +30,6 @@ pub enum Error {
     DateParseError(String, #[source] ParseError),
     #[error("Failed to parse as ByteArray {0}")]
     ByteParseError(String, #[source] DecodeError),
-    #[error("Failed to parse as Decimal {0}")]
-    DecimalParseError(String, #[source] rust_decimal::Error),
     #[error("FAiled to parse as Struct name={0}, {1}")]
     StructParseError(String, &'static str),
     #[error("No column found: name={0}")]
@@ -46,16 +43,8 @@ pub enum Error {
 }
 
 impl Row {
-    pub fn new(
-        index: Arc<HashMap<String, usize>>,
-        fields: Arc<Vec<Field>>,
-        values: Vec<Value>,
-    ) -> Row {
-        Row {
-            index,
-            fields,
-            values,
-        }
+    pub fn new(index: Arc<HashMap<String, usize>>, fields: Arc<Vec<Field>>, values: Vec<Value>) -> Row {
+        Row { index, fields, values }
     }
 
     pub fn column<T>(&self, column_index: usize) -> Result<T, Error>
@@ -91,11 +80,7 @@ pub struct Struct<'a> {
 }
 
 impl<'a> Struct<'a> {
-    pub fn new(
-        metadata: &'a StructType,
-        item: &'a Value,
-        field: &'a Field,
-    ) -> Result<Struct<'a>, Error> {
+    pub fn new(metadata: &'a StructType, item: &'a Value, field: &'a Field) -> Result<Struct<'a>, Error> {
         let kind = as_ref(item, field)?;
         let mut index = HashMap::new();
         for (i, f) in metadata.fields.iter().enumerate() {
@@ -149,9 +134,7 @@ impl<'a> Struct<'a> {
 impl TryFromValue for i64 {
     fn try_from(item: &Value, field: &Field) -> Result<Self, Error> {
         match as_ref(item, field)? {
-            Kind::StringValue(s) => s
-                .parse()
-                .map_err(|e| Error::IntParseError(field.name.to_string(), e)),
+            Kind::StringValue(s) => s.parse().map_err(|e| Error::IntParseError(field.name.to_string(), e)),
             v => kind_to_error(v, field),
         }
     }
@@ -179,8 +162,8 @@ impl TryFromValue for DateTime<Utc> {
     fn try_from(item: &Value, field: &Field) -> Result<Self, Error> {
         match as_ref(item, field)? {
             Kind::StringValue(s) => {
-                let fixed = DateTime::parse_from_rfc3339(&s)
-                    .map_err(|e| Error::DateParseError(field.name.to_string(), e))?;
+                let fixed =
+                    DateTime::parse_from_rfc3339(&s).map_err(|e| Error::DateParseError(field.name.to_string(), e))?;
                 Ok(DateTime::<Utc>::from(fixed))
             }
             v => kind_to_error(v, field),
@@ -199,8 +182,9 @@ impl TryFromValue for CommitTimestamp {
 impl TryFromValue for NaiveDate {
     fn try_from(item: &Value, field: &Field) -> Result<Self, Error> {
         match as_ref(item, field)? {
-            Kind::StringValue(s) => NaiveDate::parse_from_str(&s, "%Y-%m-%d")
-                .map_err(|e| Error::DateParseError(field.name.to_string(), e)),
+            Kind::StringValue(s) => {
+                NaiveDate::parse_from_str(&s, "%Y-%m-%d").map_err(|e| Error::DateParseError(field.name.to_string(), e))
+            }
             v => kind_to_error(v, field),
         }
     }
@@ -209,19 +193,16 @@ impl TryFromValue for NaiveDate {
 impl TryFromValue for Vec<u8> {
     fn try_from(item: &Value, field: &Field) -> Result<Self, Error> {
         match as_ref(item, field)? {
-            Kind::StringValue(s) => {
-                base64::decode(s).map_err(|e| Error::ByteParseError(field.name.to_string(), e))
-            }
+            Kind::StringValue(s) => base64::decode(s).map_err(|e| Error::ByteParseError(field.name.to_string(), e)),
             v => kind_to_error(v, field),
         }
     }
 }
 
-impl TryFromValue for rust_decimal::Decimal {
+impl TryFromValue for SpannerNumeric {
     fn try_from(item: &Value, field: &Field) -> Result<Self, Error> {
         match as_ref(item, field)? {
-            Kind::StringValue(s) => rust_decimal::Decimal::from_str(&s)
-                .map_err(|e| Error::DecimalParseError(field.name.to_string(), e)),
+            Kind::StringValue(s) => Ok(SpannerNumeric::new(s.to_string())),
             v => kind_to_error(v, field),
         }
     }
@@ -242,21 +223,11 @@ where
 {
     fn try_from(item: &Value, field: &Field) -> Result<Self, Error> {
         let maybe_array = match field.r#type.as_ref() {
-            None => {
-                return Err(Error::StructParseError(
-                    field.name.to_string(),
-                    "field type must not be none",
-                ))
-            }
+            None => return Err(Error::StructParseError(field.name.to_string(), "field type must not be none")),
             Some(tp) => tp.array_element_type.as_ref(),
         };
         let maybe_struct_type = match maybe_array {
-            None => {
-                return Err(Error::StructParseError(
-                    field.name.to_string(),
-                    "array must not be none",
-                ))
-            }
+            None => return Err(Error::StructParseError(field.name.to_string(), "array must not be none")),
             Some(tp) => tp.struct_type.as_ref(),
         };
         let struct_type = match maybe_struct_type {
@@ -367,10 +338,7 @@ mod tests {
                 ("struct_field", self.struct_field.to_kind()),
                 ("struct_field_time", self.struct_field_time.to_kind()),
                 // value from DB is timestamp. it's not string 'spanner.commit_timestamp()'.
-                (
-                    "commit_timestamp",
-                    DateTime::from(self.commit_timestamp).to_kind(),
-                ),
+                ("commit_timestamp", DateTime::from(self.commit_timestamp).to_kind()),
             ]
         }
 
