@@ -1,12 +1,9 @@
 use std::ops::{Deref, DerefMut};
 use std::sync::atomic::AtomicI64;
 
-use google_cloud_googleapis::Status;
-
 use google_cloud_googleapis::spanner::v1::{
-    transaction_options, transaction_selector, BeginTransactionRequest, ExecuteSqlRequest,
-    PartitionOptions, PartitionQueryRequest, PartitionReadRequest, ReadRequest, TransactionOptions,
-    TransactionSelector,
+    transaction_options, transaction_selector, BeginTransactionRequest, ExecuteSqlRequest, PartitionOptions,
+    PartitionQueryRequest, PartitionReadRequest, ReadRequest, TransactionOptions, TransactionSelector,
 };
 
 use crate::key::KeySet;
@@ -16,6 +13,7 @@ use crate::statement::Statement;
 use crate::transaction::{CallOptions, QueryOptions, ReadOptions, Transaction};
 use crate::value::TimestampBound;
 use chrono::{DateTime, TimeZone, Utc};
+use google_cloud_gax::grpc::Status;
 
 /// ReadOnlyTransaction provides a snapshot transaction with guaranteed
 /// consistency across reads, but does not allow writes.  Read-only transactions
@@ -51,20 +49,15 @@ impl DerefMut for ReadOnlyTransaction {
 }
 
 impl ReadOnlyTransaction {
-    pub async fn single(
-        session: ManagedSession,
-        tb: TimestampBound,
-    ) -> Result<ReadOnlyTransaction, Status> {
+    pub async fn single(session: ManagedSession, tb: TimestampBound) -> Result<ReadOnlyTransaction, Status> {
         Ok(ReadOnlyTransaction {
             base_tx: Transaction {
                 session: Some(session),
                 sequence_number: AtomicI64::new(0),
                 transaction_selector: TransactionSelector {
-                    selector: Some(transaction_selector::Selector::SingleUse(
-                        TransactionOptions {
-                            mode: Some(transaction_options::Mode::ReadOnly(tb.into())),
-                        },
-                    )),
+                    selector: Some(transaction_selector::Selector::SingleUse(TransactionOptions {
+                        mode: Some(transaction_options::Mode::ReadOnly(tb.into())),
+                    })),
                 },
             },
             rts: None,
@@ -87,7 +80,7 @@ impl ReadOnlyTransaction {
 
         let result = session
             .spanner_client
-            .begin_transaction(request, options.call_setting)
+            .begin_transaction(request, options.cancel, options.retry)
             .await;
         return match session.invalidate_if_needed(result).await {
             Ok(response) => {
@@ -187,7 +180,7 @@ impl BatchReadOnlyTransaction {
         let result = match self
             .as_mut_session()
             .spanner_client
-            .partition_read(request, None)
+            .partition_read(request, ro.call_options.cancel, ro.call_options.retry)
             .await
         {
             Ok(r) => Ok(r
@@ -206,11 +199,8 @@ impl BatchReadOnlyTransaction {
                             limit: ro.limit,
                             resume_token: vec![],
                             partition_token: x.partition_token,
-                            request_options: Transaction::create_request_options(
-                                ro.call_options.priority,
-                            ),
+                            request_options: Transaction::create_request_options(ro.call_options.priority),
                         },
-                        call_setting: ro.call_options.call_setting.clone(),
                     },
                 })
                 .collect()),
@@ -220,10 +210,7 @@ impl BatchReadOnlyTransaction {
     }
 
     /// partition_query returns a list of Partitions that can be used to execute a query against the database.
-    pub async fn partition_query(
-        &mut self,
-        stmt: Statement,
-    ) -> Result<Vec<Partition<StatementReader>>, Status> {
+    pub async fn partition_query(&mut self, stmt: Statement) -> Result<Vec<Partition<StatementReader>>, Status> {
         return self
             .partition_query_with_option(stmt, None, QueryOptions::default())
             .await;
@@ -249,7 +236,7 @@ impl BatchReadOnlyTransaction {
         let result = match self
             .as_mut_session()
             .spanner_client
-            .partition_query(request.clone(), None)
+            .partition_query(request.clone(), qo.call_options.cancel.clone(), qo.call_options.retry.clone())
             .await
         {
             Ok(r) => Ok(r
@@ -271,11 +258,8 @@ impl BatchReadOnlyTransaction {
                             partition_token: x.partition_token,
                             seqno: 0,
                             query_options: qo.optimizer_options.clone(),
-                            request_options: Transaction::create_request_options(
-                                qo.call_options.priority,
-                            ),
+                            request_options: Transaction::create_request_options(qo.call_options.priority),
                         },
-                        call_setting: qo.call_options.call_setting.clone(),
                     },
                 })
                 .collect()),
@@ -288,8 +272,9 @@ impl BatchReadOnlyTransaction {
     pub async fn execute<T: Reader + Sync + Send + 'static>(
         &mut self,
         partition: Partition<T>,
+        option: Option<CallOptions>,
     ) -> Result<RowIterator<'_>, Status> {
         let session = self.as_mut_session();
-        return RowIterator::new(session, Box::new(partition.reader)).await;
+        return RowIterator::new(session, Box::new(partition.reader), option).await;
     }
 }
